@@ -60,8 +60,7 @@ coding and non-coding regions of the exons.
 =cut
 
 package Bio::EnsEMBL::Transcript;
-$Bio::EnsEMBL::Transcript::VERSION = '112.0_56'; # TRIAL
-$Bio::EnsEMBL::Transcript::VERSION = '112.056';
+$Bio::EnsEMBL::Transcript::VERSION = '113.0.0';
 use strict;
 
 use Bio::EnsEMBL::Feature;
@@ -2853,7 +2852,7 @@ sub transfer {
 }
 
 
-=head2 recalculate_coordinates
+=head recalculate_coordinates
 
   Args       : none
   Example    : none
@@ -3143,7 +3142,18 @@ sub summary_as_hash {
   $summary_ref->{'havana_version'} = $havana_transcript->version() if defined $havana_transcript;
   $summary_ref->{'ccdsid'} = $self->ccds->display_id() if $self->ccds();
   $summary_ref->{'transcript_support_level'} = $self->tsl() if $self->tsl();
-  $summary_ref->{'tag'} = 'basic' if $self->gencode_basic();
+
+  my @tags;
+  push @tags, $self->get_all_Attributes('gencode_basic')->[0]->code if $self->gencode_basic();
+  push @tags, 'Ensembl_canonical' if $self->is_canonical();
+  push @tags, $self->get_all_Attributes('gencode_primary')->[0]->code if $self->gencode_primary();
+
+  my $mane = $self->mane_transcript();
+  if ($mane) {
+    push @tags, $mane->type() if ($mane->type());
+  }
+
+  $summary_ref->{'tag'} = \@tags if @tags;
 
   ## Stable identifier of the parent transcript this transcript was projected from
   my $proj_parent_attributes = $self->get_all_Attributes("proj_parent_t");
@@ -3155,7 +3165,7 @@ sub summary_as_hash {
 
 =head2 gencode_basic
 
-  Example       : $gencode_basic = $transcript->tag();
+  Example       : $gencode_basic = $transcript->gencode_basic();
   Description   : Returns true if gencode_basic is set
   Returns       : boolean
 =cut
@@ -3168,6 +3178,21 @@ sub gencode_basic {
   return $basic;
 }
 
+=head2 gencode_primary
+
+  Example       : $gencode_primary = $transcript->gencode_primary();
+  Description   : Returns true if gencode_primary is set
+  Returns       : boolean
+=cut
+
+sub gencode_primary {
+  my $self = shift;
+  my @attributes = @{ $self->get_all_Attributes('gencode_primary') };
+  my $primary = 0;
+  $primary = 1 if scalar(@attributes) > 0;
+  return $primary;
+}
+
 =head2 tsl
 
   Example       : $tsl = $transcript->tsl();
